@@ -150,6 +150,16 @@ static void unpause_actors_animation(ClutterActor *actor, gpointer sequencer) {
 	}
 }
 
+
+static gboolean sample_button_listened(JammoSampleButton* sample_button, gpointer data){
+	gchar* name;
+	g_object_get(sample_button,"sample-filename", &name,NULL);
+	gchar *message = g_strdup_printf("Sample '%s' listened on stage",name);
+	cem_add_to_log(message,J_LOG_USER_ACTION);
+	g_free(message);
+	return TRUE;
+}
+
 static int static_counter_for_id = 0;
 /*
 This function creates new jammo_sample_button from given parameters and put it to given parent ClutterActor.
@@ -167,6 +177,7 @@ static void create_samplebutton(gchar* themename, gchar* variation, gchar* image
 	jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
 	jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_sound);
 
+	g_signal_connect (sample_button, "listened", G_CALLBACK (sample_button_listened),NULL);
 	jammo_sample_button_set_loop_id(JAMMO_SAMPLE_BUTTON(sample_button), theme->sample_button_array->len);
 	g_ptr_array_add(theme->sample_button_array, sample_button);
 	static_counter_for_id++;
@@ -417,6 +428,34 @@ static void remove_all_icon_animations(jammo_theme* theme) {
 		}
 }
 
+/*
+Use when samplebutton is dropped to track or removed from track.
+*/
+static void log_track_activity (const gchar* event, const gchar* track_name, ClutterActor* actor, TangleScrollingActor* scrolling_actor) {
+	float x = clutter_actor_get_x(actor);
+	float offset = tangle_scrolling_actor_get_scrolling_offset_x(scrolling_actor);
+
+	gchar* name;
+	g_object_get(actor,"sample-filename", &name,NULL); //It is sample_button
+	gchar *message = g_strdup_printf("Sample '%s' %s %s-track: slot = %d",name, event, track_name, (int)(0.5+(offset+x)/WIDTH_OF_SLOT));
+	cem_add_to_log(message,J_LOG_USER_ACTION);
+	g_free(message);
+}
+
+static void on_actor_added_bottom(TangleWidget* widget, ClutterActor* actor, gpointer user_data) {
+	log_track_activity("added to", "bottom", actor,TANGLE_SCROLLING_ACTOR(user_data));
+}
+
+static void on_actor_removed_bottom(TangleWidget* widget, ClutterActor* actor, gpointer user_data) {
+	log_track_activity("removed from", "bottom", actor,TANGLE_SCROLLING_ACTOR(user_data));
+}
+static void on_actor_added_upper(TangleWidget* widget, ClutterActor* actor, gpointer user_data) {
+	log_track_activity("added to", "upper", actor,TANGLE_SCROLLING_ACTOR(user_data));
+}
+
+static void on_actor_removed_upper(TangleWidget* widget, ClutterActor* actor, gpointer user_data) {
+	log_track_activity("removed from", "upper", actor,TANGLE_SCROLLING_ACTOR(user_data));
+}
 
 
 jammo_theme* theme_create(const gchar* name,int variation, gboolean only_listening, ClutterActor* play_button) {
@@ -837,6 +876,13 @@ if (use_two_tracks) y_offset=80;
 	clutter_container_add_actor(CLUTTER_CONTAINER(view), scrolling_actor);
 
 
+	g_signal_connect(theme->bottom_track_view, "actor-added", G_CALLBACK(on_actor_added_bottom), scrolling_actor);
+	g_signal_connect(theme->bottom_track_view, "actor-removed", G_CALLBACK(on_actor_removed_bottom), scrolling_actor);
+	if (theme->upper_track_view) {
+		g_signal_connect(theme->upper_track_view, "actor-added", G_CALLBACK(on_actor_added_upper), scrolling_actor);
+		g_signal_connect(theme->upper_track_view, "actor-removed", G_CALLBACK(on_actor_removed_upper), scrolling_actor);
+	}
+
 
 	ClutterColor red = { 255, 0, 0, 128 };
 	ClutterActor* texture;
