@@ -111,7 +111,7 @@ static JammoSample* get_centermost_sample_from_loop_roll(ClutterActor* wheel) {
 	ClutterActorBox box;
 
 	offset = clutter_actor_get_height(wheel) / 2.0;
-	printf("offset = %f\n",offset);
+	//printf("offset = %f\n",offset);
 
 	GList* children;
 	for (children = tangle_widget_get_children_readonly(TANGLE_WIDGET(wheel)); children; children = children->next) {
@@ -142,7 +142,7 @@ static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer data) {
 /*
  * plays all samples from centerline of loop rolls
  */
-void fullsequencer_loop_arrow_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
+void fullsequencer_loop_play_all_clicked (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	cem_add_to_log("fullsequencer_play_all_loops-clicked",J_LOG_USER_ACTION);
 
 	//get_centermost_sample_from_loop_roll can return NULL (in error cases)
@@ -233,7 +233,9 @@ void fullsequencer_loop_cannot_fail_clicked (TangleAction *action, GObject *sour
 
 	gint index_for_combo = g_rand_int_range(random_gen, 0, number_of_cannot_fail_combos-1);
 	quad combo = cannot_fail_lists[index_for_combo];
-	printf("CannotFailCombo[%d]: %d,%d,%d,%d\n", index_for_combo,combo.r, combo.m, combo.h, combo.e);
+	gchar* message = g_strdup_printf("CannotFailCombo[%d]: %d,%d,%d,%d", index_for_combo,combo.r, combo.m, combo.h, combo.e);
+	cem_add_to_log(message,J_LOG_DEBUG);
+	g_free(message);
 
 	rotate_to_place(rhytmical_sample_looper, combo.r);
 	rotate_to_place(melodical_sample_looper, combo.m);
@@ -770,6 +772,11 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 		//printf("new_sample: '%s', '%s'\n",full_image,full_sound);
 		sample_button = jammo_sample_button_new(); //TODO: jammo_sample_button_new_with_type
 		g_object_set(sample_button,"sequencer", jammo_get_object_by_id("fullsequencer-the-sequencer"),NULL);
+
+		//With clutter-1.4 samplebutton should be in container before image_filename is set
+		// (runtime Warning: Spurious clutter_actor_allocate called for actor X which isn't a descendent of the stage!)
+		tangle_widget_add(TANGLE_WIDGET(looper),sample_button,NULL);
+
 		//printf("DEBUG: looking image: '%s' and audio: '%s'\n",full_image,full_sound);
 		jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
 		jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button), full_sound);
@@ -784,7 +791,6 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 		g_free(full_image);
 		g_free(full_sound);
 
-		tangle_widget_add(TANGLE_WIDGET(looper),sample_button,NULL);
 		counter++;
 		new_button=table[counter];
 	}
