@@ -182,7 +182,7 @@ show_points_container(ClutterActor *box,
 	//clutter_actor_hide(display_error_actor);
     return FALSE;
 }
-
+#include "../../cem/cem.h"
 void login_screen()
 {  
 			
@@ -194,7 +194,10 @@ void login_screen()
   //Print version
   gchar *pg_version;
   pg_version=PG_VERSION;		
-  g_print("pg %s\n",pg_version);
+  gchar* message = g_strdup_printf("Pen Gesture %s",pg_version);
+  cem_add_to_log(message, J_LOG_INFO);
+  g_free(message);
+
   pg_read_passwd_from_file();
   //g_print("IS NEW PASSWORD:\n",is_new_passwd);
   //Initialize clutter
