@@ -94,9 +94,10 @@ gchar *pg_read_passwd_from_file()
 	{
 		gchar string[100];
 		gchar *buffer = g_malloc(40*sizeof(gchar));
-		gchar* result = fgets(string, 20, passwd_F);
-		printf("Fgets returns: '%s' \n",result);
-		
+		gchar* result = fgets(string, 20, passwd_F);  //fgets declared with attribute warn_unused_result
+		result=result; //because of 'warning: unused variable'
+		//printf("Fgets returns: '%s' \n",result);
+
 		fclose(passwd_F);		
 		buffer=string;		
 		return buffer;		
