@@ -49,7 +49,7 @@ License:LGPL 2.1
 // volume of blow sound with FM_MODULATION algorithm
 #define BLOW_VOLUME 0.25
 
-#define SLIDER_FOLDER DATA_DIR "/virtual-instruments/slider/"
+#define SLIDER_FOLDER AUDIO_DIR "/virtual-instruments/slider/"
 
 static const GstElementDetails gst_jammo_slider_details =
 GST_ELEMENT_DETAILS ("JamMo Slider",
